# [Django Material Kit](https://app-generator.dev/docs/products/django-libs/theme-material-kit.html)

Modern UI Library for **Django**, Auth Pages (registration included) crafted on top of **Material UI Kit**, an open-source **Bootstrap** design.

- [Django Material Kit](https://app-generator.dev/docs/products/django-libs/theme-material-kit.html) - Documentation & Support Links
- [Django Material Kit](https://app-generator.dev/product/material-kit/django/) - The product that uses the library
- [Getting Started with Django](https://app-generator.dev/docs/technologies/django/index.html) - Learn how to code **Django** Projects

<br />

## **Features**

- Design: **[Material Kit](https://app-generator.dev/docs/templates/bootstrap/material-kit.html)** (Bootstrap)
- **Sections Covered**: 
  - `All pages` managed by `Django.contrib.AUTH`
  - `Registration` page
  - `Misc pages`: colors, icons, typography, blank-page 
  
<br />

![Django Material Kit - Modern UI Library for Django crafted on top of a modern Bootstrap, Open-Source Design.](https://github.com/user-attachments/assets/96b55233-cae7-4000-af56-4acb645b5ea1)

<br />

---
**[Django Material Kit](https://app-generator.dev/docs/products/django-libs/theme-material-kit.html)** - Modern Django UI Library provided by **[App-Generator](https://app-generator.dev)**
